pub struct RemoteCommand { /* private fields */ }Expand description
A checked description of one remote process. Pure data: nothing is spawned by constructing, cloning or inspecting it.
Implementations
Sourceimpl RemoteCommand
impl RemoteCommand
Sourcepub fn new(
program: impl Into<OsString>,
args: Vec<OsString>,
cwd: &Path,
) -> Result<Self, RemoteCommandError>
pub fn new( program: impl Into<OsString>, args: Vec<OsString>, cwd: &Path, ) -> Result<Self, RemoteCommandError>
Admit one command. Refuses an empty program, NUL bytes in the
program, arguments or working directory, a non-absolute working
directory, and values that cannot be represented as native
POSIX bytes. The program may be a bare name (remote PATH
lookup) or contain / (direct path).
pub fn python( script: &str, args: Vec<OsString>, cwd: &Path, ) -> Result<Self, RemoteCommandError>
pub fn program(&self) -> &RemoteProgram
pub fn args(&self) -> &[OsString]
pub fn cwd(&self) -> &Path
Sourcepub fn with_deadline(self, deadline: Duration) -> Self
pub fn with_deadline(self, deadline: Duration) -> Self
Override the wall-clock budget. Still a pure description.